#===============================================================================
# Name   : Anlise de experimento em parcela subdividida
# Author : J.C.Faria
# Date   : 14/08/2021 17:17:12
# Aim    : Ilustrar anlise em PSD
# Mail   : <<<joseclaudio.faria@gmail.com>>>
#===============================================================================
# Banzatto e Kronka (1992), apresentam o ensaio citado por Steel e Torrie (1980), no
# qual so comparadas 4 variedades de aveia e 4 tratamentos de sementes (3 produtos
# qumicos + testemunha no tratada) quanto aos efeitos sobre a produo.
#
#  A: As variedades utilizadas foram:
# A1  Vicland 1  infectada com o fungo Helminthosporium victoriae
# A2  Vicland 2  no infectada
# A3  Clinton    resistente a H. victoriae
# A4  Branch     resistente a H. victoriae
#
# As variedades foram distribudas aleatoriamente nas parcelas de cada um dos quatro
# blocos do ensaio.
#
#  B: Os tratamessntos de sementes utilizados foram:
# B1  Testemunha (no tratado)
# B2  Ceresan M
# B3  Panogen
# B4  Agros
#
# Os tratamentos de sementes foram aleatoriamente distribudos nas quatro
# subparcelas de cada parcela.

#. Leitura dos dados
dad <- read.table('psd_steel_torrie_1980.txt',
                  dec=',',
                  stringsAsFactors=T,
                  head=T)

#. Anlise
av <- aov(pro ~ blo + A + B + A*B + Error(blo/A),
          data=dad)

summary(av)

#. Carregando pacote Tukey
library(TukeyC)

cv(av)

#.. Grfico dos efeitos
par(mfrow=c(2, 1))
with(dad,
     interaction.plot(A, B, pro,
                      xlab='A',
                      ylab='Pro',
                      col='blue3',
                      lwd=2,
                      ylim=c(min(pro), max(pro))))

with(dad,
     interaction.plot(B, A, pro,
                      xlab='B',
                      ylab='Pro',
                      col='darkgreen',
                      lwd=2,
                      ylim=c(min(pro), max(pro))))

#.. Parcela: efeito principal
# Necessrio informar erro!
A <- TukeyC(av,
            error='blo:A',
            which='A')
A
A$out$MSD # 9.2 OK

#.. Subparcela: efeito principal
B <- TukeyC(av,
            which='B')
B
B$out$MSD # 4.3 OK


#.. A/B - dado parcela (Ai) / inferir supparcela (B)
#...A1/B
A1_B <- TukeyC(av,
               which='A:B',
               fl1=1)
summary(A1_B)

#...A2/B
A2_B <- TukeyC(av,
               which='A:B',
               fl1=2)
summary(A2_B)

#...A3/B
A3_B <- TukeyC(av,
               which='A:B',
               fl1=3)
summary(A3_B)

#...A4/B
A4_B <- TukeyC(av,
               which='A:B',
               fl1=4)
summary(A4_B)


#.. B/A - dado subparcela (Bi) / inferir parcela (A)
# Necessrio informar composio do erro!

#...B1/A
B1_A <- TukeyC(av,
               which='B:A',
               error='Within/blo:A',
               fl1=1)
summary(B1_A)

#...B2/A
B2_A <- TukeyC(av,
               which='B:A',
               error='Within/blo:A',
               fl1=2)
summary(B2_A)

#...B3/A
B3_A <- TukeyC(av,
               which='B:A',
               error='Within/blo:A',
               fl1=3)
summary(B3_A)

#...B4/A
B4_A <- TukeyC(av,
               which='B:A',
               error='Within/blo:A',
               fl1=4)
summary(B4_A)


#. Comparando as MSD (ver pag. 7, 8 e 9 da apostila)
#... Coparando subparcela dentro de parcela
A1_B$out$MSD # 8.58 OK

#... Coparando parcela dentro de subparcela (resduo combinado)
B1_A$out$MSD # 11.0 OK